@@ -15,8 +15,10 @@ duoComparisonDiamondPlot <- function(dat, items = NULL,
                                      xlab=c('Scores and means',
                                             'Effect size estimates'),
                                      ylab=c(NULL, NULL),
+                                     plotTitle=NULL,
                                      theme=ggplot2::theme_bw(),
                                      showLegend=TRUE,
+                                     legend.position="top",
                                      lineSize=1,
                                      drawPlot = TRUE,
                                      xbreaks="auto",
@@ -70,9 +72,11 @@ duoComparisonDiamondPlot <- function(dat, items = NULL,
                                            jitterWidth = jitterWidth,
                                            jitterHeight = jitterHeight,
                                            xlab=xlab[1],
+                                           plotTitle=plotTitle,
                                            theme=theme,
                                            ylab=ylab[1],
                                            showLegend=showLegend,
+                                           legend.position=legend.position,
                                            lineSize=lineSize,
                                            xbreaks=xbreaks,
                                            ...);
